@@ -1,7 +1,7 @@
-__version__ = "0.12"
+__version__ = "0.12.1"
 __version_vcs_info__ = {
     'branch': 'master',
-    'revid': '8021416',
-    'revno': 157}
+    'revid': '4bdec1b',
+    'revno': 160}
 __version_user_email__ = "cstavr@grnet.gr"
 __version_user_name__ = "Christos Stavrakakis"
